import { BaseOwlBoardClient } from "./client";
import { PisV2_Long, PisV2_Short } from "../types/pis/PisTypesV2";
import { validateCrs, validatePisCode, validateTiploc } from "../inputValidation/inputValidation";

export class PisClientV2 {
    private client: BaseOwlBoardClient;

    constructor(client: BaseOwlBoardClient) {
        this.client = client;
    }

    async getStopsByPis(code: string): Promise<PisV2_Long> {
        validatePisCode(code);
        const path = `/api/v2/pis/byCode/${code}`
        return this.client.makeRequest("GET", path);
    }

    //* >> This feature is not currently exposed by the API << //
    async getPisByTiplocList(tiploc_list: string[]): Promise<PisV2_Short> {
        for (const tiploc in tiploc_list) {
            validateTiploc(tiploc);
        }
        const path = `/api/v2/pis/byTiplocList/${tiploc_list}`
        return this.client.makeRequest("GET", path);
    }
    //*/

    async getPisByStartEndCRS(startCrs: string, endCrs: string): Promise<PisV2_Short> {
        validateCrs(startCrs);
        validateCrs(endCrs);
        const path = `/api/v2/pis/byStartEnd/${startCrs}/${endCrs}`
        return this.client.makeRequest("GET", path);
    }
}