import { validateCrs, validateNlc, validateReasonCode, validateStanox, validateTiploc } from "../inputValidation/inputValidation";
import { ReferenceV2_LocationReferenceCodes, ReferenceV2_LocationReferenceCodeType, ReferenceV2_ReasonCode } from "../types/reference/ReferenceTypesV2";
import { BaseOwlBoardClient } from "./client";

export class ReferenceClientV2 {
    private client: BaseOwlBoardClient;

    constructor(client: BaseOwlBoardClient) {
        this.client = client;
    }

    async defineReasonCode(reasonCode: number): Promise<ReferenceV2_ReasonCode> {
        validateReasonCode(reasonCode);
        const path = `/api/v2/ref/reasonCode/${reasonCode}`
        return this.client.makeRequest("GET", path);
    }

    async lookupLocationReference(type: ReferenceV2_LocationReferenceCodeType, referenceCode: string): Promise<ReferenceV2_LocationReferenceCodes> {
        const validators: Record<ReferenceV2_LocationReferenceCodeType, (code: string) => boolean> = {
            crs: validateCrs,
            tiploc: validateTiploc,
            nlc: validateNlc,
            stanox: validateStanox,
        };

        const validate = validators[type];
        if (!validate) {
            throw new Error(`Unsupported code type: ${type}`);
        }

        validate(referenceCode);
        
        const path = `/api/v2/ref/locationCode/${type}/${referenceCode}`
        return this.client.makeRequest("GET", path);
    }
}